It was reported that on a system with nfsboot and w/o initramfs network
fails because trying to load the PHY driver returns -ENOENT. Reason was
that due to missing initramfs the modprobe binary isn't available.
So we have to ignore error code -ENOENT.

Fixes: 13d0ab6750b2 ("net: phy: check return code when requesting PHY driver 
module")
Reported-by: Krzysztof Kozlowski <k...@kernel.org>
Signed-off-by: Heiner Kallweit <hkallwe...@gmail.com>
---
 drivers/net/phy/phy_device.c | 8 +++++---
 1 file changed, 5 insertions(+), 3 deletions(-)

diff --git a/drivers/net/phy/phy_device.c b/drivers/net/phy/phy_device.c
index 264312137..1a12acfd9 100644
--- a/drivers/net/phy/phy_device.c
+++ b/drivers/net/phy/phy_device.c
@@ -552,10 +552,12 @@ static int phy_request_driver_module(struct phy_device 
*dev, int phy_id)
 
        ret = request_module(MDIO_MODULE_PREFIX MDIO_ID_FMT,
                             MDIO_ID_ARGS(phy_id));
        /* we only check for failures in executing the usermode binary,
         * not whether a PHY driver module exists for the PHY ID
         */
-       if (IS_ENABLED(CONFIG_MODULES) && ret < 0) {
+       if (IS_ENABLED(CONFIG_MODULES) && ret < 0 && ret != -ENOENT) {
                phydev_err(dev, "error %d loading PHY driver module for ID 
0x%08x\n",
                           ret, phy_id);
@@ -552,10 +552,12 @@ static int phy_request_driver_module(struct phy_device 
        ret = request_module(MDIO_MODULE_PREFIX MDIO_ID_FMT,
                             MDIO_ID_ARGS(phy_id));
-       /* we only check for failures in executing the usermode binary,
-        * not whether a PHY driver module exists for the PHY ID
+       /* We only check for failures in executing the usermode binary,
+        * not whether a PHY driver module exists for the PHY ID.
+        * Accept -ENOENT because this may occur in case no initramfs exists,
+        * then modprobe isn't available.
         */
                return ret;
-- 
2.20.1

Reply via email to